@@ -1,7 +1,7 @@
 use 5.014;
 
 package Mojo::UserAgent::Mockable;
-$Mojo::UserAgent::Mockable::VERSION = '1.04';
+$Mojo::UserAgent::Mockable::VERSION = '1.10';
 use warnings::register;
 
 use Carp;
@@ -133,13 +133,12 @@ sub _init_playback {
             my ( $ua, $tx ) = @_;
 
             my $port         = $self->_non_blocking ? $self->server->nb_url->port : $self->server->url->port;
-            my $tx_url       = $tx->req->url->to_string;
             my $recorded_tx  = shift @{ $self->{'_transactions'} };
-            my $recorded_url = $recorded_tx->req->url->to_string;
 
             if ( $self->comparator->compare( $tx->req, $recorded_tx->req ) ) {
                 $self->_current_txn($recorded_tx);
-
+                
+                $tx->req->url($tx->req->url->clone);
                 $tx->req->url->host('')->scheme('')->port($port);
             }
             else {
@@ -228,7 +227,7 @@ Mojo::UserAgent::Mockable - A Mojo User-Agent that can record and play back requ
 
 =head1 VERSION
 
-version 1.04
+version 1.10
 
 =head1 SYNOPSIS
 
